@@ -41,7 +41,11 @@ class pysubsonic:
     def create_playlist(self, id=None, name=None, songid=None):
         params = f"playlistId={id}" if id is not None else ""
         params += f"&name={name}" if name is not None else ""
-        params += f"&songId={songid}" if songid is not None else ""
+        if type(songid) == str:
+            params += f"&songId={songid}"
+        elif type(songid) == list:
+            for sid in songid:
+                params += f"&songID={sid}"
         return self.do_request("createPlaylist", params)
     def parse_playlist_id(self, response_data):
         soup = BeautifulSoup(response_data, 'xml')
